using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.UIControls;
using CMS.GlobalHelper;
using CMS.MessageBoard;
using CMS.CMSHelper;
using CMS.SiteProvider;
using CMS.ExtendedControls;
using CMS.PortalEngine;
using CMS.SettingsProvider;

public partial class CMSModules_MessageBoards_Controls_Boards_BoardSecurity : CMSAdminEditControl
{
    #region "Variables"

    protected int mBoardId = 0;
    private int mGroupId = 0;

    #endregion


    #region "Public properties"

    /// <summary>
    /// ID of the current board
    /// </summary>
    public int BoardID
    {
        get
        {
            return this.mBoardId;
        }
        set
        {
            this.mBoardId = value;
        }
    }


    /// <summary>
    /// ID of the current group
    /// </summary>
    public int GroupID
    {
        get
        {
            return this.mGroupId;
        }
        set
        {
            this.mGroupId = value;
        }
    }

    #endregion


    #region "Page events"

    protected void Page_Load(object sender, EventArgs e)
    {
        // Initializes the controls
        SetupControls();

        if (!UrlHelper.IsPostback() && !this.IsLiveSite)
        {
            ReloadData();
        }
        else
        {
            this.addRoles.CurrentValues = GetRoles();
        }
    }


    protected void radOnlyOwner_CheckedChanged(object sender, EventArgs e)
    {
        if (radOnlyOwner.Checked)
        {
            addRoles.CurrentSelector.Enabled = false;
            btnRemoveRole.Enabled = false;
            lstRoles.Enabled = false;
        }
    }


    protected void radGroupMembers_CheckedChanged(object sender, EventArgs e)
    {
        if (radGroupMembers.Checked)
        {
            addRoles.CurrentSelector.Enabled = false;
            btnRemoveRole.Enabled = false;
            lstRoles.Enabled = false;
        }
    }


    protected void radOnlyGroupAdmin_CheckedChanged(object sender, EventArgs e)
    {
        if (radOnlyGroupAdmin.Checked)
        {
            addRoles.CurrentSelector.Enabled = false;
            btnRemoveRole.Enabled = false;
            lstRoles.Enabled = false;
        }
    }


    protected void radAllUsers_CheckedChanged(object sender, EventArgs e)
    {
        if (radAllUsers.Checked)
        {
            addRoles.CurrentSelector.Enabled = false;
            btnRemoveRole.Enabled = false;
            lstRoles.Enabled = false;
        }
    }


    protected void radOnlyUsers_CheckedChanged(object sender, EventArgs e)
    {
        if (radOnlyUsers.Checked)
        {
            btnRemoveRole.Enabled = false;
            addRoles.CurrentSelector.Enabled = false;
            lstRoles.Enabled = false;
        }
    }


    protected void radOnlyRoles_CheckedChanged(object sender, EventArgs e)
    {
        if (radOnlyRoles.Checked)
        {
            addRoles.CurrentSelector.Enabled = true ;
            btnRemoveRole.Enabled = true;
            lstRoles.Enabled = true;
        }
    }


    protected void btnRemoveRole_Click(object sender, EventArgs e)
    {
        if (!CheckPermissions("cms.messageboards", CMSAdminControl.PERMISSION_MODIFY))
        {
            return;
        }

        foreach (ListItem item in lstRoles.Items)
        {
            // Delete selected item
            if (item.Selected)
            {
                int roleId = Convert.ToInt32(item.Value);
                BoardRoleInfoProvider.RemoveRoleFromBoard(roleId, this.BoardID);
            }
        }

        ReloadRoles();
    }


    protected void addRoles_Changed()
    {
        ReloadRoles();
        pnlUpdate.Update();
    }


    protected void btnOk_Click(object sender, EventArgs e)
    {
        if (!CheckPermissions("cms.messageboards", CMSAdminControl.PERMISSION_MODIFY))
        {
            return;
        }

        BoardInfo bi = BoardInfoProvider.GetBoardInfo(this.BoardID);
        if (bi != null)
        {
            if (radOnlyUsers.Checked)
            {
                bi.BoardAccess = SecurityAccessEnum.AuthenticatedUsers;
            }

            if (radAllUsers.Checked)
            {
                bi.BoardAccess = SecurityAccessEnum.AllUsers;
            }

            if (radOnlyRoles.Checked)
            {
                bi.BoardAccess = SecurityAccessEnum.AuthorizedRoles;
            }

            if (radOnlyGroupAdmin.Visible && radOnlyGroupAdmin.Checked)
            {
                bi.BoardAccess = SecurityAccessEnum.GroupAdmin;
            }

            if (radGroupMembers.Visible && radGroupMembers.Checked)
            {
                bi.BoardAccess = SecurityAccessEnum.GroupMembers;
            }

            if (radOnlyOwner.Visible && radOnlyOwner.Checked)
            {
                bi.BoardAccess = SecurityAccessEnum.Owner;
            }

            bi.BoardUseCaptcha = chkUseCaptcha.Checked;

            BoardInfoProvider.SetBoardInfo(bi);

            lblInfo.Visible = true;
            lblInfo.Text = ResHelper.GetString("General.Changessaved");
        }
    }

    #endregion


    #region "General methods"

    /// <summary>
    /// Initializes the controls.
    /// </summary>
    private void SetupControls()
    {
        this.radAllUsers.Text = ResHelper.GetString("security.allusers");
        this.radOnlyRoles.Text = ResHelper.GetString("board.security.onlyroles");
        this.radOnlyUsers.Text = ResHelper.GetString("board.security.onlyusers");
        this.radGroupMembers.Text = ResHelper.GetString("board.security.onlygroupmembers");
        this.radOnlyGroupAdmin.Text = ResHelper.GetString("board.security.groupadmin");
        this.radOnlyOwner.Text = ResHelper.GetString("board.security.owner");
        this.btnRemoveRole.Text = ResHelper.GetString("general.remove");
        this.lblTitleComments.Text = ResHelper.GetString("board.security.commentstitle");
        this.lblTitleGeneral.Text = ResHelper.GetString("general.general");
        this.chkUseCaptcha.Text = ResHelper.GetString("board.security.usecaptcha");
        this.btnOk.Text = ResHelper.GetString("general.ok");

        this.addRoles.BoardID = this.BoardID;
        this.addRoles.CurrentSelector.IsLiveSite = this.IsLiveSite;
        this.addRoles.Changed += new CMS.FormControls.FormEngineUserControl.OnChanged(addRoles_Changed);
        this.addRoles.GroupID = this.GroupID;
        this.addRoles.IsLiveSite = this.IsLiveSite;
        this.addRoles.ShowSiteFilter = false;        
    }


    /// <summary>
    /// Reloads the listbox with roles.
    /// </summary>
    private void ReloadRoles()
    {
        // Load the roles into the ListBox
        DataSet roles = BoardRoleInfoProvider.GetBoardRoles(this.BoardID, "RoleID,RoleName");
        this.lstRoles.Items.Clear();
        this.lstRoles.DataSource = roles;
        this.lstRoles.DataBind();

        this.addRoles.CurrentSelector.Value = String.Join(";", SqlHelperClass.GetStringValues(roles.Tables[0], "RoleID"));
    }


    /// <summary>
    /// Returns board roles separated by semicolon
    /// </summary>    
    private string GetRoles()
    {
        // Load the roles into the ListBox
        DataSet roles = BoardRoleInfoProvider.GetBoardRoles(this.BoardID, "RoleID,RoleName");

        return String.Join(";", SqlHelperClass.GetStringValues(roles.Tables[0], "RoleID"));
    }


    public override void ReloadData()
    {
        base.ReloadData();

        ReloadRoles();

        BoardInfo bi = BoardInfoProvider.GetBoardInfo(this.BoardID);
        if (bi != null)
        {
            this.plcOnlyGroupAdmin.Visible = (this.GroupID > 0);
            this.plcGroupMembers.Visible = (this.GroupID > 0);
            this.plcOnlyOwner.Visible = (bi.BoardUserID > 0);

            switch (bi.BoardAccess)
            {
                // All users
                case SecurityAccessEnum.AllUsers:
                    radAllUsers.Checked = true;
                    break;

                // Authenticated users
                case SecurityAccessEnum.AuthenticatedUsers:
                    radOnlyUsers.Checked = true;
                    break;

                //Selected roles
                case SecurityAccessEnum.AuthorizedRoles:
                    radOnlyRoles.Checked = true;
                    radOnlyRoles_CheckedChanged(null, null);
                    break;

                // Group members
                case SecurityAccessEnum.GroupMembers:
                    radGroupMembers.Checked = true;
                    radGroupMembers_CheckedChanged(null, null);
                    break;

                case SecurityAccessEnum.GroupAdmin:
                    radOnlyGroupAdmin.Checked = true;
                    radOnlyGroupAdmin_CheckedChanged(null, null);
                    break;

                case SecurityAccessEnum.Owner:
                    radOnlyOwner.Checked = true;
                    radOnlyOwner_CheckedChanged(null, null);
                    break;

                default:
                    radAllUsers.Checked = true;
                    break;
            }

            this.lstRoles.Enabled = radOnlyRoles.Checked;
            this.btnRemoveRole.Enabled = radOnlyRoles.Checked;
            this.addRoles.CurrentSelector.Enabled = radOnlyRoles.Checked;
            this.chkUseCaptcha.Checked = bi.BoardUseCaptcha;

            this.addRoles.ReloadData();
            this.addRoles.DataBind();
        }

    }

    #endregion
}
